/*#############################################################
File Name       : ex1_LM6029ACW_HelloWorld.c
Author          : Grant Phillips
Date Modified   : 25/08/2013
Compiler        : Keil ARM-MDK (uVision V4.70.0.0)
Tested On       : STM32F3-Discovery

Description     : Example program that writes "Hello World!" in
									normal mode and then inverted to a LM6029ACW 
									graphics LCD.       

Requirements    : * STM32F3-Discovery Board
									* Make sure the LM6029ACW_F3.c file is in the 
                    same folder than the project
									* Define the SET and RESET functions for the
										output port pins in the LM6029ACW_F3.c
										library
									* Do the proper GPIO initialization for the
										output port pins in LM6029ACW_Init() in the
										LM6029ACW_F3.c library
              
Circuit         : * The LM6029ACW is connected as follows:
										(see the LM6029ACW datasheet for a complete
										description of each pin).
										Vss (LM6029ACW pin 1)	-	GND
										Vdd (LM6029ACW pin 2)	-	3.3V
										DB7 (pin3)						-	PD7
										DB6 (pin4)						-	PD6
										DB5 (pin5)						-	PD5
										DB4 (pin6)						-	PD4
										DB3 (pin7)						-	PD3
										DB2 (pin8)						-	PD2
										DB1 (pin9)						-	PD1
										DB0 (pin10)						-	PD0
										/RD (pin11)						-	PA1
										/WR (pin12)						-	PA2
										RS (pin13)						-	PA3
										/RES (pin14)					-	PA4
										/CS (pin15)						-	PA8
										BLA (pin16)						-	3.3V

See the STM32F3-Discovery User Manual (UM1570) for the block 
diagram of the STM32F303VCT6 processor (p13), a summary of
the GPIO connections (p21-29) and the schematic diagram (p31-34)

##############################################################*/

/* #includes -------------------------------------------------*/
#include "main.h"																								//main library to include for device drivers, peripheral drivers, etc.
#include "LM6029ACW_F3.c"																				//for the LM6029ACW graphics lcd functions on the STM32F3-Discovery

/* #defines --------------------------------------------------*/

/* #function prototypes --------------------------------------*/

/* #global variables -----------------------------------------*/
GPIO_InitTypeDef        GPIO_InitStructure;											//structure used for setting up a GPIO port
RCC_ClocksTypeDef 			RCC_Clocks;															//structure used for setting up the SysTick Interrupt



// Unused global variables that have to be included to ensure correct compiling */
// ###### DO NOT CHANGE ######
// ===============================================================================
__IO uint32_t TimingDelay = 0;																	//used with the Delay function
__IO uint8_t DataReady = 0;
__IO uint32_t USBConnectTimeOut = 100;
__IO uint32_t UserButtonPressed = 0;
__IO uint8_t PrevXferComplete = 1;
// ===============================================================================



int main(void)
{
	/* Set the SysTick Interrupt to occur every 1ms) */
	RCC_GetClocksFreq(&RCC_Clocks);
	if (SysTick_Config(RCC_Clocks.HCLK_Frequency / 1000))
		while(1);																										//will end up in this infinite loop if there was an error with Systick_Config
	
	LM6029ACW_Init();												//initialize the lcd
	
	LM6029ACW_PutStr("Hello World!", 1);		//print text in normal mode
	LM6029ACW_PutStr("         ", 1);		  	//print 9 spaces in normal mode
	
	LM6029ACW_PutStr("Hello World!", 0);		//print text in invert mode
	
	/* Main program loop */
  while (1)
  {
		//do nothing
  }	
}





// -------------------------------------------------------------------------------

// Function to insert a timing delay of nTime
// ###### DO NOT CHANGE ######
void Delay(__IO uint32_t nTime)
{
  TimingDelay = nTime;

  while(TimingDelay != 0);
}

// Function to Decrement the TimingDelay variable.
// ###### DO NOT CHANGE ######
void TimingDelay_Decrement(void)
{
  if (TimingDelay != 0x00)
  { 
    TimingDelay--;
  }
}

// Unused functions that have to be included to ensure correct compiling
// ###### DO NOT CHANGE ######
// =======================================================================
uint32_t L3GD20_TIMEOUT_UserCallback(void)
{
  return 0;
}

uint32_t LSM303DLHC_TIMEOUT_UserCallback(void)
{
  return 0;
}
// =======================================================================



