/*#############################################################
File Name       : ex2_LM6029ACW_char_functions.c
Author          : Grant Phillips
Date Modified   : 25/08/2013
Compiler        : Keil ARM-MDK (uVision V4.70.0.0)
Tested On       : STM32F3-Discovery

Description     : Example program that demonstrates the use of
                  the character functions in the LM6029ACW_F3.c
									library (LM6029ACW_ClrScr(), LM6029ACW_GotoXY(), 
									LM6029ACW_PutChar(), LM6029ACW_PutStr()) and 
                  the use of string function sprintf().      

Requirements    : * STM32F3-Discovery Board
									* Make sure the LM6029ACW_F3.c file is in the 
                    same folder than the project
									* Define the SET and RESET functions for the
										output port pins in the LM6029ACW_F3.c
										library
									* Do the proper GPIO initialization for the
										output port pins in LM6029ACW_Init() in the
										LM6029ACW_F3.c library
              
Circuit         : * The LM6029ACW is connected as described in
										ex1_LM6029ACW_HelloWorld.c

See the STM32F3-Discovery User Manual (UM1570) for the block 
diagram of the STM32F303VCT6 processor (p13), a summary of
the GPIO connections (p21-29) and the schematic diagram (p31-34)

##############################################################*/

/* #includes -------------------------------------------------*/
#include "main.h"																								//main library to include for device drivers, peripheral drivers, etc.
#include "LM6029ACW_F3.c"																				//for the LM6029ACW graphics lcd functions on the STM32F3-Discovery

/* #defines --------------------------------------------------*/

/* #function prototypes --------------------------------------*/

/* #global variables -----------------------------------------*/
GPIO_InitTypeDef        GPIO_InitStructure;											//structure used for setting up a GPIO port
RCC_ClocksTypeDef 			RCC_Clocks;															//structure used for setting up the SysTick Interrupt



// Unused global variables that have to be included to ensure correct compiling */
// ###### DO NOT CHANGE ######
// ===============================================================================
__IO uint32_t TimingDelay = 0;																	//used with the Delay function
__IO uint8_t DataReady = 0;
__IO uint32_t USBConnectTimeOut = 100;
__IO uint32_t UserButtonPressed = 0;
__IO uint8_t PrevXferComplete = 1;
// ===============================================================================



int main(void)
{
	char buf[21];                    				//declare a string variable of 21 chars   
  unsigned char i;
	
	/* Set the SysTick Interrupt to occur every 1ms) */
	RCC_GetClocksFreq(&RCC_Clocks);
	if (SysTick_Config(RCC_Clocks.HCLK_Frequency / 1000))
		while(1);																										//will end up in this infinite loop if there was an error with Systick_Config
	
	LM6029ACW_Init();												//initialize the lcd
		
	/* Main program loop */
  while (1)
  {
		LM6029ACW_ClrScr(0);								  //clear the display and clear the dots (=0)
		Delay(1000);
		LM6029ACW_GotoXY(0,0);								//set the character cursor to col=0, row=0
		LM6029ACW_PutStr("Hello World!", 1);	//display text in normal mode
		Delay(500);
		
		LM6029ACW_GotoXY(0,1);								//set the character cursor to col=0, row=1
		for(i=1;i<=10;i++)
    {
			sprintf(buf, "%d " , i);   					//print a integer value and space to the buf string
      LM6029ACW_PutStr(buf,1);            //write a string variable to the LCD in normal mode
      Delay(500);
    }
		
		sprintf(buf, "Good Bye");  						//store a string constant into the buf string variable
    LM6029ACW_GotoXY(0,2);								//set the character cursor to col=0, row=2 
    for(i=0;i<=7;i++)
    {
       LM6029ACW_PutChar(buf[i], 1);      //display a character on the LCD in normal mode
       Delay(500);
    }
		
		LM6029ACW_GotoXY(12,2);								//set the character cursor to col=12, row=2  
    for(i=65;i<=72;i++)
    {
      LM6029ACW_PutChar(i, 1);  					//display a integer value as a byte onn the LCD in normal mode
																					//driver will convert it to the correpsonding ASCII char
      Delay(500);
    }
		
		// repeat, but clear LCD with black dots.  Print normal mode //
		LM6029ACW_ClrScr(1);								  //clear the display and fill with dots (=1)
		Delay(1000);
		LM6029ACW_GotoXY(0,0);								//set the character cursor to col=0, row=0
		LM6029ACW_PutStr("Hello World!", 1);	//display text in normal mode
		Delay(500);
		
		LM6029ACW_GotoXY(0,1);								//set the character cursor to col=0, row=1
		for(i=1;i<=10;i++)
    {
			sprintf(buf, "%d " , i);   					//print a integer value and space to the buf string
      LM6029ACW_PutStr(buf,1);            //write a string variable to the LCD in normal mode
      Delay(500);
    }
		
		sprintf(buf, "Good Bye");  						//store a string constant into the buf string variable
    LM6029ACW_GotoXY(0,2);								//set the character cursor to col=0, row=2 
    for(i=0;i<=7;i++)
    {
       LM6029ACW_PutChar(buf[i], 1);      //display a character on the LCD in normal mode
       Delay(500);
    }
		
		LM6029ACW_GotoXY(12,2);								//set the character cursor to col=12, row=2  
    for(i=65;i<=72;i++)
    {
      LM6029ACW_PutChar(i, 1);  					//display a integer value as a byte onn the LCD in normal mode
																					//driver will convert it to the correpsonding ASCII char
      Delay(500);
    }
		
		// repeat, but clear LCD with clear dots.  Print inverted mode //
		LM6029ACW_ClrScr(0);								  //clear the display and fill with clear dots (=0)
		Delay(1000);
		LM6029ACW_GotoXY(0,0);								//set the character cursor to col=0, row=0
		LM6029ACW_PutStr("Hello World!", 0);	//display text in inverted mode
		Delay(500);
		
		LM6029ACW_GotoXY(0,1);								//set the character cursor to col=0, row=1
		for(i=1;i<=10;i++)
    {
			sprintf(buf, "%d " , i);   					//print a integer value and space to the buf string
      LM6029ACW_PutStr(buf,0);            //write a string variable to the LCD in inverted mode
      Delay(500);
    }
		
		sprintf(buf, "Good Bye");  						//store a string constant into the buf string variable
    LM6029ACW_GotoXY(0,2);								//set the character cursor to col=0, row=2 
    for(i=0;i<=7;i++)
    {
       LM6029ACW_PutChar(buf[i], 0);      //display a character on the LCD in inverted mode
       Delay(500);
    }
		
		LM6029ACW_GotoXY(12,2);								//set the character cursor to col=12, row=2  
    for(i=65;i<=72;i++)
    {
      LM6029ACW_PutChar(i, 0);  					//display a integer value as a byte onn the LCD in inverted mode
																					//driver will convert it to the correpsonding ASCII char
      Delay(500);
    }
		
		// repeat, but clear LCD with black dots.  Print inverted mode //
		LM6029ACW_ClrScr(1);								  //clear the display and fill with dots (=1)
		Delay(1000);
		LM6029ACW_GotoXY(0,0);								//set the character cursor to col=0, row=0
		LM6029ACW_PutStr("Hello World!", 0);	//display text in inverted mode
		Delay(500);
		
		LM6029ACW_GotoXY(0,1);								//set the character cursor to col=0, row=1
		for(i=1;i<=10;i++)
    {
			sprintf(buf, "%d " , i);   					//print a integer value and space to the buf string
      LM6029ACW_PutStr(buf,0);            //write a string variable to the LCD in inverted mode
      Delay(500);
    }
		
		sprintf(buf, "Good Bye");  						//store a string constant into the buf string variable
    LM6029ACW_GotoXY(0,2);								//set the character cursor to col=0, row=2 
    for(i=0;i<=7;i++)
    {
       LM6029ACW_PutChar(buf[i], 0);      //display a character on the LCD in inverted mode
       Delay(500);
    }
		
		LM6029ACW_GotoXY(12,2);								//set the character cursor to col=12, row=2  
    for(i=65;i<=72;i++)
    {
      LM6029ACW_PutChar(i, 0);  					//display a integer value as a byte onn the LCD in inverted mode
																					//driver will convert it to the correpsonding ASCII char
      Delay(500);
    }
  }	
}





// -------------------------------------------------------------------------------

// Function to insert a timing delay of nTime
// ###### DO NOT CHANGE ######
void Delay(__IO uint32_t nTime)
{
  TimingDelay = nTime;

  while(TimingDelay != 0);
}

// Function to Decrement the TimingDelay variable.
// ###### DO NOT CHANGE ######
void TimingDelay_Decrement(void)
{
  if (TimingDelay != 0x00)
  { 
    TimingDelay--;
  }
}

// Unused functions that have to be included to ensure correct compiling
// ###### DO NOT CHANGE ######
// =======================================================================
uint32_t L3GD20_TIMEOUT_UserCallback(void)
{
  return 0;
}

uint32_t LSM303DLHC_TIMEOUT_UserCallback(void)
{
  return 0;
}
// =======================================================================



