/*#############################################################
File Name       : ex4_LM6029ACW_char_graphics.c
Author          : Grant Phillips
Date Modified   : 25/08/2013
Compiler        : Keil ARM-MDK (uVision V4.70.0.0)
Tested On       : STM32F3-Discovery

Description     : Example program that demonstrates the use of
                  the graphics functions combined with the 
									character functions.

Requirements    : * STM32F3-Discovery Board
									* Make sure the LM6029ACW_F3.c file is in the 
                    same folder than the project
									* Define the SET and RESET functions for the
										output port pins in the LM6029ACW_F3.c
										library
									* Do the proper GPIO initialization for the
										output port pins in LM6029ACW_Init() in the
										LM6029ACW_F3.c library
              
Circuit         : * The LM6029ACW is connected as described in
										ex1_LM6029ACW_HelloWorld.c

See the STM32F3-Discovery User Manual (UM1570) for the block 
diagram of the STM32F303VCT6 processor (p13), a summary of
the GPIO connections (p21-29) and the schematic diagram (p31-34)

##############################################################*/

/* #includes -------------------------------------------------*/
#include "main.h"																								//main library to include for device drivers, peripheral drivers, etc.
#include "LM6029ACW_F3.c"																				//for the LM6029ACW graphics lcd functions on the STM32F3-Discovery

/* #defines --------------------------------------------------*/

/* #function prototypes --------------------------------------*/

/* #global variables -----------------------------------------*/
GPIO_InitTypeDef        GPIO_InitStructure;											//structure used for setting up a GPIO port
RCC_ClocksTypeDef 			RCC_Clocks;															//structure used for setting up the SysTick Interrupt



// Unused global variables that have to be included to ensure correct compiling */
// ###### DO NOT CHANGE ######
// ===============================================================================
__IO uint32_t TimingDelay = 0;																	//used with the Delay function
__IO uint8_t DataReady = 0;
__IO uint32_t USBConnectTimeOut = 100;
__IO uint32_t UserButtonPressed = 0;
__IO uint8_t PrevXferComplete = 1;
// ===============================================================================



int main(void)
{  
  unsigned char i;
	
	/* Set the SysTick Interrupt to occur every 1ms) */
	RCC_GetClocksFreq(&RCC_Clocks);
	if (SysTick_Config(RCC_Clocks.HCLK_Frequency / 1000))
		while(1);																										//will end up in this infinite loop if there was an error with Systick_Config
	
	LM6029ACW_Init();												//initialize the lcd
		
	/* Main program loop */
  while (1)
  {
		LM6029ACW_ClrScr(0);								  						//clear the display and clear the dots (=0)
		LM6029ACW_GotoXY(1,3);
		LM6029ACW_PutStr("Text under graphics", 1);				//print text before drawing graphics over it - normal mode
		LM6029ACW_DrawLine(0,0,127,63,1);									//Draw a line from the top left corner to bottom right in color=1
		LM6029ACW_DrawLine(0,0,0,63,1);										//Draw a line from the top left corner to bottom left in color=1
		LM6029ACW_DrawLine(0,63,127,63,1);								//Draw a line from the bottom left corner to bottom right in color=1
		LM6029ACW_DrawCircle(30,40,20,0,1);								//Draw a circle with radius=10, fill=0, color=1
		LM6029ACW_DrawCircle(100,24,20,1,1);							//Draw a circle with radius=10, fill=0, color=1
		LM6029ACW_DrawPixel(30,40,1);											//Draw a pixel in the left circle with color=1
		LM6029ACW_GotoXY(1,4);
		LM6029ACW_PutStr("Text over graphics", 1);				//print text over the graphics - normal mode
		for(i=0;i<10;i++)																	//Flash a pixel in the right circle 10 times by alternating the color between 0 and 1
		{
			LM6029ACW_DrawPixel(100,24,0);									//Draw a pixel in the right circle with color=0
			Delay(200);
			LM6029ACW_DrawPixel(100,24,1);									//Draw a pixel in the right circle with color=1
			Delay(200);
		}
		Delay(500);
		
		//repeat, but this time on a black background and clear foreground
		LM6029ACW_ClrScr(1);								  						//clear the display and fill with dots (=1)
		LM6029ACW_GotoXY(1,3);
		LM6029ACW_PutStr("Text under graphics", 0);				//print text before drawing graphics over it - inverted mode
		LM6029ACW_DrawLine(0,0,127,63,0);									//Draw a line from the top left corner to bottom right in color=0
		LM6029ACW_DrawLine(0,0,0,63,0);										//Draw a line from the top left corner to bottom left in color=0
		LM6029ACW_DrawLine(0,63,127,63,0);								//Draw a line from the bottom left corner to bottom right in color=0
		LM6029ACW_DrawCircle(30,40,20,0,0);								//Draw a circle with radius=10, fill=0, color=0
		LM6029ACW_DrawCircle(100,24,20,1,0);							//Draw a circle with radius=10, fill=0, color=0
		LM6029ACW_DrawPixel(30,40,0);											//Draw a pixel in the left circle with color=0
		LM6029ACW_GotoXY(1,4);
		LM6029ACW_PutStr("Text over graphics", 0);				//print text over the graphics - inverted mode
		for(i=0;i<20;i++)																	//Flash a pixel in the right circle 10 times by alternating the color between 0 and 1
		{
			LM6029ACW_DrawPixel(100,24,2);									//Draw a pixel in the right circle with color=2 (toggle color)
			Delay(200);
		}
		Delay(500);
  }	
}





// -------------------------------------------------------------------------------

// Function to insert a timing delay of nTime
// ###### DO NOT CHANGE ######
void Delay(__IO uint32_t nTime)
{
  TimingDelay = nTime;

  while(TimingDelay != 0);
}

// Function to Decrement the TimingDelay variable.
// ###### DO NOT CHANGE ######
void TimingDelay_Decrement(void)
{
  if (TimingDelay != 0x00)
  { 
    TimingDelay--;
  }
}

// Unused functions that have to be included to ensure correct compiling
// ###### DO NOT CHANGE ######
// =======================================================================
uint32_t L3GD20_TIMEOUT_UserCallback(void)
{
  return 0;
}

uint32_t LSM303DLHC_TIMEOUT_UserCallback(void)
{
  return 0;
}
// =======================================================================



